@@ -40,16 +40,23 @@ def main():
     version = current.installed_version()
     if not version:
         print("Local binary not found, going to install")
+        version = "0.0"
     latest_version = remote.get_latest_version()
     if utils.cast_version(version) >= utils.cast_version(latest_version):
         print("Latest already installed")
         sys.exit(0)
     os.chdir(C().tmp_folder)
-    filename, hash_ = remote.download_with_hash(latest_version)
+    tar_path, hash_ = remote.download_with_hash(latest_version)
     if hash_ != remote.get_hash_control(latest_version):
         raise ValueError("Hash mismatch!")
-    shutil.unpack_archive(filename)
-    Path(filename).unlink()
+    shutil.unpack_archive(tar_path)
+    Path(tar_path).unlink()
+    bk_folder = Path(f"{C().binaries_path}_old")
+    install_folder = Path(C().binaries_path)
+    if bk_folder.exists():
+        bk_folder.unlink()
+    if install_folder.exists():
+        install_folder.rename(bk_folder)
     Path('./firefox').rename(C().binaries_path)
     utils.write_desktop_file()
     utils.write_profile_desktop_file()
